include <Navestidlo-sokl_SD2.scad>
/*
Elektrobox - sklada se z kvadru a rozsireneho podstavce.

standX x standYTop je rozmer podstavce nahore, u kvadru.
standXBottom x standY je rozmer podstavce dole, u zakladny.

Podivny rozsireny podstavec je provedeny jako Polyhedron
*/
standX = 4.2;
standXBottom = 2.8;
standY = 4.0;
standYTop = 3.0;
standLowH = 1.2;

module podstavecDole() {

standYdiff = (standY - standYTop) / 2;
standXdiff = (standX - standXBottom) / 2;

cubepoints = [
    [standXdiff, 0, 0],              // 0
    [standX - standXdiff, 0, 0],         // 1
    [standX - standXdiff, standY, 0],    // 2
    [standXdiff, standY, 0],         // 3
    
    [0, standYdiff, standLowH],                    // 4
    [standX, standYdiff, standLowH],               // 5
    [standX, standY - standYdiff, standLowH],      // 6
    [0, standY - standYdiff, standLowH],           // 7
];
cubefaces = [
    [ 0, 1, 2, 3],
    [ 7, 6, 5, 4],
    [ 0, 3, 7, 4],
    [ 5, 6, 2, 1],
    [ 4, 5, 1, 0],
    [ 6, 7, 3, 2]
];

translate([- standX / 2, - standY / 2, 0])  polyhedron(
    cubepoints,
    cubefaces,
    convexity = 10
);
}

module podstavec() {
    union() {
        podstavecDole();
        translate([- standX / 2, - standYTop / 2, standLowH]) cube([standX, standYTop, 4]);
    }
}

// ---------------------------------------------------------------------------------
stozar_prumer = 2;
dutina_prumer = 1.0;

/*
Teio stozaru. 
- Valec, 
- nahore krouzek 
- dole podstavec
- to cele proderavele dirou
*/
module stozar() {
    rotate([90, 0, 0]) 
    difference() {
        union() {
            translate([0, 0, 48]) cylinder(h = 1, r = (2.7 / 2), $fn=50);
            cylinder(h=50, r= stozar_prumer / 2, $fn=50);
//            translate([0, 0, 5]) podstavec();
        }
        cylinder(h=50, r=dutina_prumer / 2, $fn=50);
    }
}

/*
Stupacky. Spousta malych valecku, po 2.5mm
- posunute z roviny z=0 tal, aby pri preriznuti pro tisk v polovine
    byly 'nahore'
- posunute na stozaru nad patku
*/
zebrik_delkaStupne = 1;
zebrik_tloustka = 0.6   ;
zebrik_tloustkaR = zebrik_tloustka / 2;
module zebrik() {
    // posunout nad patku, a tesne nad rovinu z=0
    translate([0, -12, 0/* - 0.02 */])
    // sklopit do roviny
    rotate([0, 90, 0]) 
    for (x = [0 : -2.5 : -35]) {
        translate([0, x, 0]) rotate([0, 0, 30]) cylinder($fn=6, h=zebrik_delkaStupne + 0.1, r=zebrik_tloustkaR);
    }
}

module stozar_s_zebrikem() {
    union() {
        stozar();
        // ta 0.1 je zanoreni stupacky do valce stozaru
        translate([(1 - 0.1), 0, 0.00 ]) zebrik();
        translate([-(1 + 0.9), 0, 0.00 ]) zebrik();
    }
}

/*
4 uhelnik, vytazeny do prostoru. Posunuty po stozaru na 'sve misto'
*/
rameno_heightDiff = 0.3;

module rameno() {
    translate([0, -12 - 12*2.5 - 0.4, -0.7])
    linear_extrude(height = 1.4)
    polygon(points=[
        [0, 0], [0, -1.7], [4.6, -1.7 - rameno_heightDiff], [4.6, -1.7 - rameno_heightDiff + 1.2]
    ]);
}

module celyStozar() {
union() {
    stozar_s_zebrikem();
    translate([1 - 0.1, 0, 0]) rameno();
}
}


module stozarHorniPulka() {
    difference() {
        celyStozar();
        translate([-10, -60, -10]) cube([20, 60, 10]);
    }
}

module stozarDolniPulka() {
    rotate([0, 180, 0])
    difference() {
        celyStozar();
        translate([-10, -60, 0]) cube([20, 60, 10]);
    }
}

difference() {

union() {
    translate([0, 8, 0]) difference() {
        celyStozar();
        translate([0, -44, 0]) rotate([40, 90, 0])   cylinder($fn=10, h = 10, r1 = 0.6, r2 = 0.6);
        translate([0.96, -44.68, 0]) rotate([3.8, 90, 0])   cylinder($fn=10, h = 10, r1 = 0.6, r2 = 0.6);
    }
    rotate([90,90,0]) scale([2,2,2]) sokl();
}
rotate([90, 0, 0])  cylinder(h=50, r=dutina_prumer / 2, $fn=50);
}